OpenStack Scenarios
===================

This section contains details for the most popular OpenStack scenarios.
For the full list of Shaker scenarios please refer to :ref:`catalog`.

.. toctree::
    :maxdepth: 2

    full_l2
    full_l3_east_west
    full_l3_north_south
